@@ -1,16 +1,13 @@
 import logging
 from collections import OrderedDict, defaultdict
 from datetime import datetime
-from typing import Any, Callable, Dict, Optional
+from typing import Any, Callable, Dict, List, Optional, Union
 
-from dvc.exceptions import InvalidArgumentError
-from dvc.repo import locked
+from dvc.repo import Repo, locked  # pylint: disable=unused-import
 from dvc.repo.experiments.base import ExpRefInfo
-from dvc.repo.experiments.executor.base import ExecutorInfo
-from dvc.repo.experiments.utils import fix_exp_head
 from dvc.repo.metrics.show import _gather_metrics
 from dvc.repo.params.show import _gather_params
-from dvc.scm.base import SCMError
+from dvc.scm import iter_revs
 from dvc.utils import error_handler, onerror_collect
 
 logger = logging.getLogger(__name__)
@@ -26,6 +23,8 @@ def _collect_experiment_commit(
     running=None,
     onerror: Optional[Callable] = None,
 ):
+    from dvc.dependency import ParamsDependency, RepoDependency
+
     res: Dict[str, Optional[Any]] = defaultdict(dict)
     for rev in repo.brancher(revs=[exp_rev]):
         if rev == "workspace":
@@ -42,10 +41,30 @@ def _collect_experiment_commit(
         if params:
             res["params"] = params
 
+        res["deps"] = {
+            dep.def_path: {
+                "hash": dep.hash_info.value,
+                "size": dep.meta.size,
+                "nfiles": dep.meta.nfiles,
+            }
+            for dep in repo.index.deps
+            if not isinstance(dep, (ParamsDependency, RepoDependency))
+        }
+
+        res["outs"] = {
+            out.def_path: {
+                "hash": out.hash_info.value,
+                "size": out.meta.size,
+                "nfiles": out.meta.nfiles,
+            }
+            for out in repo.index.outs
+            if not (out.is_metric or out.is_plot)
+        }
+
         res["queued"] = stash
         if running is not None and exp_rev in running:
             res["running"] = True
-            res["executor"] = running[exp_rev].get(ExecutorInfo.PARAM_LOCATION)
+            res["executor"] = running[exp_rev].get("location")
         else:
             res["running"] = False
             res["executor"] = None
@@ -72,7 +91,9 @@ def _collect_experiment_commit(
 def _collect_experiment_branch(
     res, repo, branch, baseline, onerror: Optional[Callable] = None, **kwargs
 ):
-    exp_rev = repo.scm.resolve_rev(branch)
+    from dvc.scm import resolve_rev
+
+    exp_rev = resolve_rev(repo.scm, branch)
     prev = None
     revs = list(repo.scm.branch_revs(exp_rev, baseline))
     for rev in revs:
@@ -102,47 +123,35 @@ def _collect_experiment_branch(
 
 @locked
 def show(
-    repo,
+    repo: "Repo",
     all_branches=False,
     all_tags=False,
-    revs=None,
+    revs: Union[List[str], str, None] = None,
     all_commits=False,
     sha_only=False,
     num=1,
     param_deps=False,
     onerror: Optional[Callable] = None,
 ):
+
     if onerror is None:
         onerror = onerror_collect
 
     res: Dict[str, Dict] = defaultdict(OrderedDict)
 
-    if num < 1:
-        raise InvalidArgumentError(f"Invalid number of commits '{num}'")
+    if not any([revs, all_branches, all_tags, all_commits]):
+        revs = ["HEAD"]
+    if isinstance(revs, str):
+        revs = [revs]
 
-    if revs is None:
-        revs = []
-        for n in range(num):
-            try:
-                head = fix_exp_head(repo.scm, f"HEAD~{n}")
-                revs.append(repo.scm.resolve_rev(head))
-            except SCMError:
-                break
-
-    revs = OrderedDict(
-        (rev, None)
-        for rev in repo.brancher(
-            revs=revs,
-            all_branches=all_branches,
-            all_tags=all_tags,
-            all_commits=all_commits,
-            sha_only=True,
-        )
+    found_revs: Dict[str, List[str]] = {"workspace": []}
+    found_revs.update(
+        iter_revs(repo.scm, revs, num, all_branches, all_tags, all_commits)
     )
 
     running = repo.experiments.get_running_exps()
 
-    for rev in revs:
+    for rev in found_revs:
         res[rev]["baseline"] = _collect_experiment_commit(
             repo,
             rev,
@@ -177,7 +186,7 @@ def show(
             )
         # collect queued (not yet reproduced) experiments
         for stash_rev, entry in repo.experiments.stash_revs.items():
-            if entry.baseline_rev in revs:
+            if entry.baseline_rev in found_revs:
                 if stash_rev not in running or not running[stash_rev].get(
                     "last"
                 ):
